Changelog
=========

Only important changes are mentioned below.


v0.5 (2014-07-23)
-----------------

* Removed useless custom Exception classes not used anymore
* Added model mixin creation class for holding additional helper functions
* Fixed broken links in docs
* Added manager subclass to docs
* Added admin to docs


v0.4 (2014-07-23)
-----------------

* Moved generation of FormField from model to Form
* Improved documentation


v0.3 (2014-07-22)
-----------------

* Improved documentation


v0.2 (2014-07-20)
-----------------

* Avoid using a global registry for registered apps in favour of a setting variable
* Improved documentation


v0.1 (2014-07-18)
-----------------

* First stable version released
